# Onirix Embed SDK


![Version](https://img.shields.io/badge/version-1.18.1-blue.svg?cacheSeconds=2592000)
[![Documentation](https://img.shields.io/badge/documentation-yes-brightgreen.svg)](https://docs.onirix.com/onirix-sdk/embed-sdk)
[![Twitter: onirix](https://img.shields.io/twitter/follow/onirix.svg?style=social)](https://twitter.com/onirix)

Take control of your Onirix augmented reality experiences. Responds to user interaction and acts on the 3D content of the scene.

This library acts as a wrapper of **window.postMessage** for simplifying communication with Onirix AR experiences.  Not only can you use it in the online code editor of Onirix Studio projects, you can also connect to your scene loaded in an iFrame.

**Take Onirix experiences to the next level.**

Full documentation available at <a href="https://docs.onirix.com/onirix-sdk/embed-sdk" target="_blank">Onirix Docs</a>.

## Install

```sh
npm install @onirix/embed-sdk
```
Or include the dependency within the HTML head tag:

```html
<head>
    <script src="https://cdn.jsdelivr.net/npm/@onirix/embed-sdk@1.18.1/+esm">
</head>
```

Or as ESM modules:

```js
import OnirixEmbedSDK from "https://cdn.jsdelivr.net/npm/@onirix/embed-sdk@1.18.1/+esm";
```

## Usage

Just create an instance of  our EmbedSDK and execute the connect method. From that moment on you will be able to subscribe to the events that occur in the scene and you will be able to execute actions on the elements of the experience.

```js
import OnirixEmbedSDK from "https://cdn.jsdelivr.net/npm/@onirix/embed-sdk@1.18.1/+esm";
const embedSDK = new OnirixEmbedSDK();
await embedSDK.connect();

embedSDK.subscribe(OnirixEmbedSDK.Events.ELEMENT_CLICK, (params) => {
    console.log('somebody clicks me!', params);
});

embedSDK.enable(elementOid);
```

If you have embedded an Onirix Studio experience in your application through an iframe, you must pass the Html element of the iFrame to the EmbedSDK constructor.

```js
import OnirixEmbedSDK from "https://cdn.jsdelivr.net/npm/@onirix/embed-sdk@1.18.1/+esm";
const iframeElement = document.getElementById("<iframe_element_id>");
const embedSDK = new OnirixEmbedSDK(iframeElement);
await embedSDK.connect();
```

> Make sure that the iFrame is already loaded before instantiating the EmbedSDK.

See the complete list of events and actions in [our documentation](https://docs.onirix.com/onirix-sdk/embed-sdk).

## Author

👤 **Onirix**

* Website: www.onirix.com
* Twitter: [@onirix](https://twitter.com/onirix)
* Github: [@onirix-ar](https://github.com/onirix-ar)
* LinkedIn: [@onirixar](https://linkedin.com/in/onirixar)